from setuptools import setup
setup(name='xyz01',
      version='0.2',
      description='The test for pypi',
      url='https://github.com',
      author='Test ',
      author_email='test@test.com',
      license='MIT',
      packages=['xyz01'],
      zip_safe=False)
